@@ -4,7 +4,7 @@ use hkdf::Hkdf;
 #[cfg(feature = "ring")]
 use ring_compat::digest::Sha512;
 
-#[cfg(feature = "default")]
+#[cfg(not(feature = "ring"))]
 use sha2::Sha512;
 
 use core::convert::TryInto;
